@@ -31,7 +31,7 @@ class SqliteWrapper(object):
 
     def get(self, statement, *args):
         con, cur = self.execute(statement, *args)
-        return cur.fetchone() if cur.rowcount > 0 else None
+        return cur.fetchone()
 
     def all(self, statement, *args):
         con, cur = self.execute(statement, *args)
